@@ -1,5 +1,7 @@
 """aimmo autoconfig"""
 
+from .csp_config import CSP_CONFIG
+
 DEFAULT_SETTINGS = {"AUTOCONFIG_INDEX_VIEW": "aimmo/home", "STATIC_URL": "/static/"}
 
 SETTINGS = {
@@ -27,3 +29,5 @@ SETTINGS = {
     ],
     "USE_TZ": True,
 }
+
+SETTINGS.update(CSP_CONFIG)
